ytree\.arbor\.frontends\.ytree\.arbor\.YTreeArbor
=================================================

.. currentmodule:: ytree.arbor.frontends.ytree.arbor

.. autoclass:: YTreeArbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~YTreeArbor.__init__
      ~YTreeArbor.add_alias_field
      ~YTreeArbor.add_analysis_field
      ~YTreeArbor.add_derived_field
      ~YTreeArbor.is_grown
      ~YTreeArbor.is_setup
      ~YTreeArbor.save_arbor
      ~YTreeArbor.select_halos
      ~YTreeArbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~YTreeArbor.arr
      ~YTreeArbor.box_size
      ~YTreeArbor.field_info
      ~YTreeArbor.hubble_constant
      ~YTreeArbor.quan
      ~YTreeArbor.size
      ~YTreeArbor.trees
      ~YTreeArbor.unit_registry
   
   